(install)=

# Installing tsbrowse
```
python3 -m pip install tsbrowse
```

To install the development version:
```
python3 -m pip install git+https://github.com/tskit-dev/tsbrowse
```
Please also see the documentation on [Contributing](contributing.md).

For an introduction to tsbrowse, see [Introduction](intro.md)